@@ -43,47 +43,22 @@ Base::Base(MProcess &mproc, PartMan &pman, Ui::MeInstall &ui,
     // calculate required disk space
     proc.exec("du", {"-sb", bootSource}, nullptr, true);
     partman.bootSpaceNeeded = proc.readOut().section('\t', 0, 0).toLongLong();
-    const long long spaceBlock = 134217728; // 128MB
-    partman.bootSpaceNeeded += 2*spaceBlock - (partman.bootSpaceNeeded % spaceBlock);
 
-    QSettings livesettings("/live/config/initrd.out", QSettings::NativeFormat);
-    QString SQFILE_FULL = livesettings.value("SQFILE_FULL", "/live/boot-dev/antiX/linuxfs").toString();
-    if (!QFile::exists(SQFILE_FULL + ".info")) {
-        SQFILE_FULL = livesettings.value("TORAM_MP", "/live/to-ram").toString() + "/antiX/linuxfs";
+    QSettings liveInfo("/live/config/initrd.out", QSettings::IniFormat);
+    QString linuxfs = liveInfo.value("SQFILE_FULL", "/live/boot-dev/antiX/linuxfs").toString();
+    if (!QFile::exists(linuxfs + ".info")) {
+        linuxfs = liveInfo.value("TORAM_MP", "/live/to-ram").toString() + "/antiX/linuxfs";
     }
-    qDebug() << "linuxfs file is at : " << SQFILE_FULL;
-    const QSettings squashinfo(SQFILE_FULL + ".info");
+    const QSettings squashInfo(linuxfs + ".info", QSettings::IniFormat);
     bool floatOK = false;
-    partman.rootSpaceNeeded = 1024 * squashinfo.value("UncompressedSizeKB").toFloat(&floatOK);
+    partman.rootSpaceNeeded = 1024 * squashInfo.value("UncompressedSizeKB").toFloat(&floatOK);
     if (!floatOK) {
-        //conservative but fast. Factors are same as used in live-remaster. Using "du -sb ..." here is so slow, people thought the installer crashed.
-        //get compression factor by reading the linuxfs squasfs file, if available
-        long long compression_factor;
-        int linuxfs_compression_type = 0; //default conservative
-        if (QFileInfo::exists(SQFILE_FULL)) {
-            proc.shell("dd if=" + SQFILE_FULL + " bs=1 skip=20 count=2 status=none"
-                " 2>/dev/null | od -An -tdI", nullptr, true);
-            linuxfs_compression_type = proc.readOut().toInt();
-        }
-        // gzip, xz, or lz4
-        switch (linuxfs_compression_type) {
-            case 1: // gzip
-                compression_factor = 30;
-                break;
-            case 2: // lzo, not used by antiX
-            case 3: // lzma, not used by antiX
-            case 5: // lz4
-                compression_factor = 42;
-                break;
-            case 4: // xz
-            default: // anythng else or linuxfs not reachable (toram), should be pretty conservative
-                compression_factor = 25;
-        }
-        qDebug() << "linuxfs compression type is" << linuxfs_compression_type << "compression factor is" << compression_factor;
-        proc.shell("df /live/linux --output=used --total |tail -n1", nullptr, true);
-        partman.rootSpaceNeeded = (proc.readOut().toLongLong() * 1024 * 100) / compression_factor;
+        rootSources.prepend("-sb");
+        proc.exec("du", rootSources, nullptr, true);
+        rootSources.removeFirst();
+        partman.rootSpaceNeeded = proc.readOut().section('\t', 0, 0).toLongLong();
     }
-    qDebug() << "linuxfs file size is " << partman.rootSpaceNeeded;
+    qDebug() << "Image:" << linuxfs << partman.rootSpaceNeeded << floatOK;
     // Account for persistent root.
     if (QFileInfo::exists("/live/perist-root")) {
         proc.shell("df /live/persist-root --output=used --total |tail -n1", nullptr, true);
@@ -92,14 +67,8 @@ Base::Base(MProcess &mproc, PartMan &pman, Ui::MeInstall &ui,
         // probaby conservative, as rootfs will likely have some overlap with linuxfs.
         partman.rootSpaceNeeded += rootfs_size;
     }
-    // Account for inodes and file tails.
-    struct statvfs svfs;
-    if (statvfs("/live/linux", &svfs) == 0) {
-        partman.rootSpaceNeeded += (svfs.f_files - svfs.f_ffree) * sysconf(_SC_PAGESIZE);
-    }
 
     qDebug() << "Minimum space:" << partman.bootSpaceNeeded << "(boot)," << partman.rootSpaceNeeded << "(root)";
-
 }
 
 bool Base::install()
